==> mfc-api-model-0.1.5-sources.jar: com/valor/mfc/vms/api/model/user/UserStatusDo.java <==
package com.valor.mfc.vms.api.model.user;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

import java.io.Serializable;

/**
 * @ClassName: UserStatusDo
 * @Auther: gardfield
 * @Date: 12/20/2019
 * @Version 1.0
 * @Description:
 */
public class UserStatusDo extends AbstractPrintable implements Serializable {
    private Long accountId;
    private Integer accountType; //0:设备登录用户；1： 账号用户
    private Integer bizStatus=-1; //1:VALID,2:EXPIRED,3:TO_BE_EXPIRED
    private Integer userType=-1;  //  EServiceType.ST_FREE(0),ST_PRE_PAID(1), ST_PAID(2);
    private Boolean isRenew; // 是否续费
    private Integer trial = 0; //是否免费试用
    private Long expireTs;

    public UserStatusDo() {
    }

    public UserStatusDo(Long accountId, Integer accountType) {
        this.accountId = accountId;
        this.accountType = accountType;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public Integer getBizStatus() {
        return bizStatus;
    }

    public void setBizStatus(Integer bizStatus) {
        this.bizStatus = bizStatus;
    }

    public Integer getUserType() {
        return userType;
    }

    public void setUserType(Integer userType) {
        this.userType = userType;
    }

    public Boolean getRenew() {
        return isRenew;
    }

    public void setRenew(Boolean renew) {
        isRenew = renew;
    }

    public Integer getTrial() {
        return trial;
    }

    public void setTrial(Integer trial) {
        this.trial = trial;
    }

    public Long getExpireTs() {
        return expireTs;
    }

    public void setExpireTs(Long expireTs) {
        this.expireTs = expireTs;
    }
}

==> mfc-api-model-0.1.6-sources.jar: com/valor/mfc/vms/api/model/user/UserStatusDo.java <==
package com.valor.mfc.vms.api.model.user;

import com.valor.mfc.vms.api.model.common.AbstractPrintable;

import java.io.Serializable;

/**
 * @ClassName: UserStatusDo
 * @Auther: gardfield
 * @Date: 12/20/2019
 * @Version 1.0
 * @Description:
 */
public class UserStatusDo extends AbstractPrintable implements Serializable {
    private Long accountId;
    private Integer accountType; //0:设备登录用户；1： 账号用户
    private Integer bizStatus=-1; //1:VALID,2:EXPIRED,3:TO_BE_EXPIRED
    private Integer userType=-1;  //  EServiceType.ST_FREE(0),ST_PRE_PAID(1), ST_PAID(2);
    private Boolean isRenew; // 是否续费
    private Integer trial = 0; //是否免费试用
    private Long expireTs;
    private Long productId;

    public UserStatusDo() {
    }

    public UserStatusDo(Long accountId, Integer accountType) {
        this.accountId = accountId;
        this.accountType = accountType;
    }

    public Long getAccountId() {
        return accountId;
    }

    public void setAccountId(Long accountId) {
        this.accountId = accountId;
    }

    public Integer getAccountType() {
        return accountType;
    }

    public void setAccountType(Integer accountType) {
        this.accountType = accountType;
    }

    public Integer getBizStatus() {
        return bizStatus;
    }

    public void setBizStatus(Integer bizStatus) {
        this.bizStatus = bizStatus;
    }

    public Integer getUserType() {
        return userType;
    }

    public void setUserType(Integer userType) {
        this.userType = userType;
    }

    public Boolean getRenew() {
        return isRenew;
    }

    public void setRenew(Boolean renew) {
        isRenew = renew;
    }

    public Integer getTrial() {
        return trial;
    }

    public void setTrial(Integer trial) {
        this.trial = trial;
    }

    public Long getExpireTs() {
        return expireTs;
    }

    public void setExpireTs(Long expireTs) {
        this.expireTs = expireTs;
    }

    public Long getProductId() { return productId; }

    public void setProductId(Long productId) { this.productId = productId; }
}
